@@ -76,7 +76,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 
 					if errBody == nil {
 						response := Response{}
-						xml.Unmarshal(body, &response)
+						if err := xml.Unmarshal(body, &response); err != nil {
+							continue
+						}
 
 						if res.StatusCode >= 200 && res.StatusCode < 300 && response.Error == nil {
 							s1.Verified = true
